@@ -14,7 +14,8 @@
 
 #include "docentrytraverser.h"
 
-namespace KHC {
+namespace KHC
+{
 
 class SearchEngine;
 class View;
@@ -24,15 +25,15 @@ class GrantleeFormatter;
 class SearchTraverser : public QObject, public DocEntryTraverser
 {
     Q_OBJECT
-  public:
-    SearchTraverser( SearchEngine *engine, int level );
+public:
+    SearchTraverser(SearchEngine *engine, int level);
     ~SearchTraverser() override;
 
-    void process( DocEntry * ) override;
+    void process(DocEntry *) override;
 
-    void startProcess( DocEntry * ) override;
+    void startProcess(DocEntry *) override;
 
-    DocEntryTraverser *createChild( DocEntry * ) override;
+    DocEntryTraverser *createChild(DocEntry *) override;
 
     DocEntryTraverser *parentTraverser() override;
 
@@ -40,17 +41,17 @@ class SearchTraverser : public QObject, public DocEntryTraverser
 
     void finishTraversal() override;
 
-    void setWords( const QString &words );
+    void setWords(const QString &words);
 
-  protected:
-    void connectHandler( SearchHandler *handler );
-    void disconnectHandler( SearchHandler *handler );
+protected:
+    void connectHandler(SearchHandler *handler);
+    void disconnectHandler(SearchHandler *handler);
 
-  protected Q_SLOTS:
-    void showSearchResult( SearchHandler *, DocEntry *, const QString &result );
-    void showSearchError( SearchHandler *, DocEntry *, const QString &error );
+protected Q_SLOTS:
+    void showSearchResult(SearchHandler *, DocEntry *, const QString &result);
+    void showSearchError(SearchHandler *, DocEntry *, const QString &error);
 
-  private:
+private:
     const int mMaxLevel;
 
     SearchEngine *mEngine = nullptr;
@@ -59,41 +60,46 @@ class SearchTraverser : public QObject, public DocEntryTraverser
     DocEntry *mEntry = nullptr;
     QString mJobData;
 
-    QList<QPair<DocEntry *, QString> > mResults;
-    QList<QPair<DocEntry *, QString> > *mResultsPtr;
+    QList<QPair<DocEntry *, QString>> mResults;
+    QList<QPair<DocEntry *, QString>> *mResultsPtr;
     QString mWords;
 
     QMap<SearchHandler *, int> mConnectCount;
 };
 
-
 class SearchEngine : public QObject
 {
     Q_OBJECT
-  public:
-    enum Operation { And, Or };
+public:
+    enum Operation {
+        And,
+        Or
+    };
 
-    explicit SearchEngine( View * );
+    explicit SearchEngine(View *);
     ~SearchEngine();
 
     bool initSearchHandlers();
 
-    bool search( const QString & words, const QString & method = QStringLiteral("and"), int matches = 5,
-                 const QStringList & scope = QStringList() );
+    bool search(const QString &words, const QString &method = QStringLiteral("and"), int matches = 5, const QStringList &scope = QStringList());
 
     GrantleeFormatter *grantleeFormatter() const;
     View *view() const;
 
-    static QString substituteSearchQuery( const QString &query,
-      const QString &identifier, const QStringList &words, int maxResults,
-      Operation operation, const QString &lang, const QString& binary );
+    static QString substituteSearchQuery(const QString &query,
+                                         const QString &identifier,
+                                         const QStringList &words,
+                                         int maxResults,
+                                         Operation operation,
+                                         const QString &lang,
+                                         const QString &binary);
 
     void finishSearch();
 
     /**
       Append error message to error log.
     */
-    void logError( DocEntry *entry, const QString &msg );
+    void logError(DocEntry *entry, const QString &msg);
 
     /**
       Return error log.
@@ -102,19 +108,19 @@ class SearchEngine : public QObject
 
     bool isRunning() const;
 
-    SearchHandler *handler( const QString &documentType ) const;
+    SearchHandler *handler(const QString &documentType) const;
 
     QStringList words() const;
     int maxResults() const;
     Operation operation() const;
 
-    bool canSearch( DocEntry * );
-    bool needsIndex( DocEntry * );
+    bool canSearch(DocEntry *);
+    bool needsIndex(DocEntry *);
 
-  Q_SIGNALS:
+Q_SIGNALS:
     void searchFinished();
 
-  private:
+private:
     bool mSearchRunning;
     QString mSearchResult;
 
@@ -133,10 +139,10 @@ class SearchEngine : public QObject
 
     SearchTraverser *mRootTraverser = nullptr;
 
-    QMap<QString, QSharedPointer<SearchHandler> > mHandlers;
+    QMap<QString, QSharedPointer<SearchHandler>> mHandlers;
 };
 
 }
 
-#endif //KHC_SEARCHENGINE_H
+#endif // KHC_SEARCHENGINE_H
 // vim:ts=2:sw=2:et
